.. _refimagefindpars:

******************************************************************
Refmagefindpars: Source finding parameters for the reference image
******************************************************************
This interface provides a mechanism for setting the parameters used by the
built-in source finding algorithm based on the published algorithms
used by DAOFIND. These settings apply only to source finding
in the reference images.

.. automodule:: drizzlepac.refimagefindpars
   :members:
   :undoc-members:
